Hermes::Engine.routes.draw do
  namespace :api do
    namespace :dmo do
      resources :housing_request_shares, only: :create do
        collection do
          get :find_by_housing_request_id
        end
      end
      resources :housing_request_shares, only: :show, controller: '/hermes/api/housing_request_shares' # no authenticated routes
      resources :applicants do
        member do
          get 'eligible_offers'
          post 'switch'

        end
        collection do
          get :find_by_nud
        end
      end

      resources :entity_validations
      resources :entity_reservations
      resources :entities do
        member do
          put 'switch_manual_mode'
          post 'add_points', to: "entities#add_points"
          get 'user_rights'
        end
        collection do
          get 'admin_search'
        end
        resources :housing_request_entity_form_levels
      end
      resources :housing_request_entity_forms do
        get :actives, on: :collection
        get :show_request, on: :member
      end
      resources :entity_codes, only: [:index, :create, :destroy]
      resources :lessor_objective_histories
      resources :housing_applications do
        collection do
          post :attribution
        end
      end
      resources :untensed_areas

      post 'housing_applications/update_status', to: "housing_applications#update_status"

      resources :housing_offers do
        collection do
          get 'with_validated_applications/:id', action: 'with_validated_applications_for'
          get 'with_validated_applications'
          get 'reference_exist'
        end
        member do
          resources :pictures, only: [:create, :update, :destroy]
          get 'eligible_requests'
          get 'entity_statuses'
          get 'selected_applications'
          post 'selected_applications', to: 'housing_offers#post_selected_applications'
          get "all_applications",  to: 'housing_offers#all_applications'
          get 'history'
          get 'detailed_score'
          get 'score_position'
          post 'add_housing_channel'
          post 'remove_housing_channel'
        end
      end
      generate_notifications_routes # Helper to generate all notifications routes

      resources :housing_channels
      resources :housing_channel_settings
      resources :housing_offer_expiration_settings
      resources :public_housing_offers do
        collection do
          get 'test'
        end
      end
      resources :public_housing_offers_test
      resources :users, only: [:show, :create, :update] do
        post :switch, on: :member
      end
      resources :user_rights, only: [:show, :index, :create, :destroy]
      resources :operations
      resources :management_areas
      resources :lessor_contacts

      get 'rex/root_elements', to: 'rex#root_elements'
      get 'rex/subsidiaries', to: 'rex#subsidiaries'
      get 'rex/:id', to: 'rex#show', as: :show


      resources :housing_requests do
        collection do
          get 'clp_details'
          get 'admin_search'
          post 'send_message'
          post 'send_flux_thirty'
        end
        member do
          get 'zip'
          get 'entity_note'
          get 'internal_note'
          put 'update_internal_note'
          put 'update_entity_note'
          get 'housing_request_folder'
          get 'entity_requests'
          get 'waiting_points'
          get 'spent_points'
          post 'add_points_to_housing_request'
          post 'housing_request_folder/start_treatment', to: "housing_requests#start_treatment"
          post 'add_housing_channel'
          post 'validate_housing_channel'
          post 'update_from_sne'
          post 'validate_code'
          post 'notify'
        end
      end

      post 'required_documents/:id/send_files', to: "required_documents#send_files"
      get 'required_documents/:id/historical_status', to: "required_documents#historical_status"
      get 'required_documents/:id', to: "required_documents#show"
      patch 'required_documents/:id', to: "required_documents#update"
      put 'required_documents/:id', to: "required_documents#update"
      delete 'required_documents/:id/files', to: "required_documents#delete_files"
      resources :lessors do
        collection do
          get 'admin_search'
        end
        member do
          get 'all_objectives'
          get 'active_objectives'
          put 'switch_manual_mode'
          get 'current_operation_names'
          put :add_user
          put :remove_user
        end
      end

      resources :lessor_objectives
      resources :nuds do
        member do
          post 'send_pin_code_on_mail'
          post 'authentify_with_pin_code'
        end
      end
      resources :thresholds
      resources :contact_groups
      resources :statuses do
        get :applications_history, on: :collection
      end

      namespace :public_forms do
        get 'captcha'
        post 'confirm'
      end

      get '/nuds/sne_department_list', to: "nuds#sne_department_list"
      resources :reservation_holders

      get 'doc', to: "documentation#show_doc"
      get 'changelog', to: "documentation#show_changelog"
    end # end of /api/dmo
  end # end of /api

  namespace :admin do # /admin
    resources :thresholds, only: %i[index create] do # /admin/thresholds
      collection do
        get 'download_csv'
      end
    end

    resources :housing_requests, only: %i[index create destroy update], path: :housing_requests do # /admin/housing_requests
    end

    resources :untensed_areas, only: %i[index create destroy update], path: :areas do # /admin/areas
      collection do
        get 'download_csv'
      end
    end
  end # end of /admin



  get '/hermes/gedfile/*path', to: "geds#file", :format => false
end
